Perform Differential Expression Analysis (DEA) on CyTOF data
tof_dea.RdThis function performs differential expression analysis on the cell clusters
contained within a `tof_tbl` using one of three methods
("diffcyt", "glmm", and "ttest"). It wraps the members of the `tof_dea_*`
function family: tof_dea_diffcyt,
tof_dea_lmm, and tof_dea_ttest.
Usage
tof_dea(tof_tibble, method = c("diffcyt", "glmm", "ttest"), ...)Arguments
- tof_tibble
A `tof_tbl` or a `tibble`.
- method
A string indicating which statistical method should be used. Valid values include "diffcyt", "lmm", and "ttest".
- ...
Additional arguments to pass onto the `tof_dea_*` function family member corresponding to the chosen method.
Value
A tibble or nested tibble containing the differential abundance results
from the chosen method. See tof_dea_diffcyt,
tof_dea_lmm, and tof_dea_ttest for details.
See also
Other differential expression analysis functions:
tof_dea_diffcyt(),
tof_dea_lmm(),
tof_dea_ttest()